@@ -7,18 +7,17 @@ test_that("Whole workflow works consistently", {
   # Beta diversity metrics
   expect_snapshot({
     set.seed(42)
-    gridding(meta, btf) %>%
-      resampling(measure = "ABUNDANCE", resamps = 1L) %>%
-      getBetaMetrics(measure = "ABUNDANCE") %>%
+    gridding(meta, btf) |>
+      resampling(measure = "ABUNDANCE", resamps = 1L) |>
+      getBetaMetrics(measure = "ABUNDANCE") |>
       getLinearRegressions(divType = "beta")
   })
 
   expect_snapshot({
     set.seed(42)
-    gridding(meta, btf) %>%
-      resampling(measure = "BIOMASS", resamps = 1L) %>%
-      getBetaMetrics(measure = "BIOMASS") %>%
+    gridding(meta, btf) |>
+      resampling(measure = "BIOMASS", resamps = 1L) |>
+      getBetaMetrics(measure = "BIOMASS") |>
       getLinearRegressions(divType = "beta")
   })
-
 })
